@@ -1,11 +1,8 @@
 use x86_64::structures::idt::{InterruptDescriptorTable, InterruptStackFrame};
 use lazy_static::lazy_static;
-use crate::print;
-use crate::println;
-use crate::gdt;
+use crate::{gdt, print, println};
 use pic8259::ChainedPics;
 use spin;
-// convert to one line
 
 pub const PIC_1_OFFSET: u8 = 32;
 pub const PIC_2_OFFSET: u8 = PIC_1_OFFSET + 8;
@@ -18,6 +15,7 @@ lazy_static!
 	{
 		let mut idt = InterruptDescriptorTable::new();
 		idt.breakpoint.set_handler_fn(breakpnt_handler);
+		idt[IntrIdx::Keyboard.asusize()].set_handler_fn(keyboard_interrupt_handler);
 		unsafe
 		{
 			idt.double_fault
@@ -41,6 +39,7 @@ pub fn idtinit()
 pub enum IntrIdx
 {
 	Timer = PIC_1_OFFSET,
+	Keyboard,
 }
 
 impl IntrIdx
@@ -70,14 +69,44 @@ extern "x86-interrupt" fn doubleflt_handler(stackframe: InterruptStackFrame, _er
 	panic!("[EXC] DOUBLE-FAULT\n{:#?}", stackframe);
 }
 
+extern "x86-interrupt" fn keyboard_interrupt_handler(_stackframe: InterruptStackFrame)
+{
+	use x86_64::instructions::port::Port;
+	let mut port = Port::new(0x60);
+	let scancode: u8 = unsafe { port.read() };
+	{
+		let key = match scancode
+		{
+			0x02 => Some('1'),
+			0x03 => Some('2'),
+			0x04 => Some('3'),
+			0x05 => Some('4'),
+			0x06 => Some('5'),
+			0x07 => Some('6'),
+			0x08 => Some('7'),
+			0x09 => Some('8'),
+			0x0a => Some('9'),
+			0x0b => Some('0'),
+			_ => None,
+		};
+	if let Some(key) = key
+	{
+		print!("{}", key);
+	}
+	unsafe
+	{
+		PICS.lock().notify_end_of_interrupt(IntrIdx::Keyboard.asu8());
+	}
+	};
+}
+
 
 extern "x86-interrupt" fn timer_interrupt_handler(_stackframe: InterruptStackFrame)
 {
 	print!(".");
 	unsafe
 	{
-		PICS.lock()
-			.notify_end_of_interrupt(IntrIdx::Timer.asu8());
+		PICS.lock().notify_end_of_interrupt(IntrIdx::Timer.asu8());
 	}
 }
 
